@@ -1,4 +1,4 @@
-# Copyright 2019 Katteli Inc.
+# Copyright 2019-2021 Katteli Inc.
 # TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,9 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 __author__ = "Vitaliy Zakaznikov"
-__version__ = "1.7.210813.1013350"
+__version__ = "1.7.210830.1013013"
+__repository__ = "https://github.com/testflows/TestFlows-Core.git"
+__commit__ = "98fe0f29c8b977b4f64e630b7ed281231e2e95be"
+__branch__ = "master"
 __license__ = f"""
-Copyright 2019 Katteli Inc.
+Copyright 2019-2021 Katteli Inc.
 TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 
 Licensed under the Apache License, Version 2.0 (the "License");
